voicetools.Voice
================

.. inheritance-diagram:: abjad.tools.voicetools.Voice.Voice.Voice
   :private-bases:

.. autoclass:: abjad.tools.voicetools.Voice.Voice.Voice

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.contents_duration

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.duration_in_seconds

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.engraver_consists

   .. note:: Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.engraver_removals

   .. note:: Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.format

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.is_semantic

   .. note:: Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.leaves

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.marks

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.music

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.override

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.parent

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.preprolated_duration

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.prolated_duration

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.prolation

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.set

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.spanners

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.context_name

   .. note:: Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.is_nonsemantic

   .. note:: Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.is_parallel

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.voicetools.Voice.Voice.Voice.name

   .. note:: Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

Methods
-------

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.append

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.extend

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.index

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.insert

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.pop

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.remove

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

Special Methods
---------------

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__add__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__contains__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__delitem__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__getitem__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__iadd__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__imul__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__len__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__mul__

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__radd__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__repr__

   .. note:: Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__rmul__

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__setitem__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.voicetools.Voice.Voice.Voice.__str__

   .. note:: Inherited from `__builtin__.object`
